export interface MyAnimeListUser {
    id: number
    name: string
    picture: string
    gender: string
    birthday: string
    location: string
    joinedAt: string
    AnimeStatistics: AnimeStatistics
    timeZone: string
    isSupporter: boolean

}

export interface AnimeStatistics {
    numItemsWatching: number 
    numItemsCompleted: number 
    numItemsOnHold: number 
    numItemsDropped: number 
    numItemsPlanToWatch: number 
    numItems: number 
    numDaysWatched: number 
    numDaysWatching: number 
    numDaysCompleted: number 
    numDaysOnHold: number 
    numDaysDropped: number 
    numDays: number 
    numEpisodes: number 
    numTimesRewatched: number 
    meanScore: number 
}

export interface MALWatchlist {
    data: [MALAnimeFromList]
    paging: Paging
}

export interface MALAnimeFromList {
    node: Node
    listStatus: ListStatus | MyListStatus
}

export interface Node {
    id: number
    title: string
    mainPicture: MainPicture
}

export interface MainPicture {
    medium: string
    large: string
}

export interface ListStatus {
    status: string
    score: number
    numEpisodesWatched: number
    isRewatching: boolean
    updated_at: string
    startDate: string
    finishDate: string
}

export interface Paging {
    previous: string
    next: string
}

export interface MALAnime {
    id: number;
    title: string;
    main_picture: {
        large: string;
        medium: string;
    };
    alternative_titles: {
        synonyms: string[];
        en: string;
        ja: string;
    };
    start_date: string;
    end_date: string;
    synopsis: string;
    mean: number;
    rank: number;
    popularity: number;
    num_list_users: number;
    num_scoring_users: number;
    nsfw: string;
    genres: {
        id: number;
        name: string;
    }[];
    created_at: string;
    updated_at: string;
    media_type: string;
    status: string;
    my_list_status: MyListStatus;
    num_episodes: number;
    start_season: {
        year: number;
        season: string;
    };
    broadcast: {
        day_of_the_week: string;
        start_time: string;
    };
    source: string;
    average_episode_duration: number;
    rating: string;
    studios: {
        id: number;
        name: string;
    }[];
    pictures: {
        large: string;
        medium: string;
    }[];
    background: string;
    related_anime: {
        node: MALAnime;
        relation_type: string;
        relation_type_formatted: string;
    }[];
    recommendations: {
        node: MALAnime;
        num_recommendations: number;
    }[];
    Statistics: {
        num_list_users: number;
        Status: {
            watching: string;
            completed: string;
            on_hold: string;
            dropped: string;
            plan_to_watch: string;
        };
    };
}

export interface MyListStatus {
    status: string;
    score: number;
    num_episodes_watched: number;
    is_rewatching: boolean;
    start_date: string;
    finish_date: string;
    priority: number;
    num_times_rewatched: number;
    rewatch_value: number;
    tags: string[];
    comments: string;
    updated_at: string;
}

export interface MALUploadStatus {
    status: string
    is_rewatching: boolean
    score: number
    num_watched_episodes: number
    num_times_rewatched: number
    comments: string
}